@@ -85,6 +85,9 @@ def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projecti
 
     for record in get_shard_records(streams_client, stream_arn, shard, seq_number):
         LOGGER.info("Record got here  : %s",record)
+        if record['dynamodb']['SequenceNumber']==seq_number :
+            LOGGER.info("Skipping sync of shard %s as no records updated")
+            continue
         if record['eventName'] == 'REMOVE':
             record_message = deserializer.deserialize_item(record['dynamodb']['Keys'])
             record_message[SDC_DELETED_AT] = singer.utils.strftime(record['dynamodb']['ApproximateCreationDateTime'])
